<footer>
    <div class="container">
        <div class="footer-inner">
            <span class="footer-copy">&copy; 2026 AgentForms. All rights reserved.</span>
            <div class="footer-links">
                <a href="/privacy">Privacy</a>
                <a href="/terms">Terms</a>
            </div>
        </div>
    </div>
</footer>
