// login.js — extracted from login.html
// Data injected via window.__DATA__

document.querySelectorAll('.auth-tab').forEach(function(tab) {
        tab.addEventListener('click', function(e) {
            e.preventDefault();
            e.stopPropagation();
            document.querySelectorAll('.auth-tab').forEach(function(t) { t.classList.remove('active'); });
            document.querySelectorAll('.auth-tab-content').forEach(function(c) { c.classList.remove('active'); });
            this.classList.add('active');
            document.getElementById('tab-' + this.getAttribute('data-tab')).classList.add('active');
        });
    });